@@ -39,16 +39,17 @@ __weak const struct intel_thc_hidspi_info *soc_get_thc_hidspi_info(void) { retur
 static const struct drivers_intel_touch_config *get_driver_config(const struct device *dev)
 
 {
-	const struct drivers_intel_touch_config none_driver_config;
 	const struct drivers_intel_touch_config *config = dev->chip_info;
-	const struct drivers_intel_touch_config *devices[TH_SENSOR_MAX] = {
-		[TH_SENSOR_NONE] = &none_driver_config,
-		[TH_SENSOR_WACOM] = &wacom_touch_config,
-		[TH_SENSOR_ELAN] = &elan_touch_config,
-		[TH_SENSOR_HYNITRON] = &hynitron_touch_config,
-		[TH_SENSOR_GENERIC] = config
-	};
-	return devices[config->connected_device];
+	switch (config->connected_device) {
+	case TH_SENSOR_WACOM:    return &wacom_touch_config;
+	case TH_SENSOR_ELAN:     return &elan_touch_config;
+	case TH_SENSOR_GOOGLE:   return &google_touch_config;
+	case TH_SENSOR_HYNITRON: return &hynitron_touch_config;
+	case TH_SENSOR_GENERIC:  return config;
+	case TH_SENSOR_NONE:     return NULL;
+	/* no default so that we get an error in case someone forgets to add a case here */
+	}
+	return NULL;
 }
 
 /* Use only Device-tree definition. */
@@ -67,6 +68,16 @@ static const struct drivers_intel_touch_config *get_driver_config(const struct d
 	 (((const struct drivers_intel_touch_config *)(device)->chip_info)->soc_## intf .field) :	\
 	 (_soc_## intf ##_info->field))
 
+/*
+ * Device-tree definition takes precedence over static drivers device-specific over static
+ * drivers SoC-specific definition.
+ */
+#define touch_dev_soc_get(device, interface, field)  \
+	((((const struct drivers_intel_touch_config *)(device)->chip_info)->dev_## interface .intf.interface.field) ? :  \
+	(get_driver_config(device)->dev_## interface .intf.interface.field) ? :  \
+	((((const struct drivers_intel_touch_config *)(device)->chip_info)->soc_## interface .field) ? :  \
+	(_soc_## interface ##_info->field)))
+
 static const char *touch_acpi_name(const struct device *dev)
 {
 	return touch_get(dev, name) ? : INTEL_THC0_NAME;
@@ -104,7 +115,16 @@ static const char *touch_acpi_name(const struct device *dev)
 		acpigen_write_return_ ## type(value);				\
 	}
 
-touch_soc_acpigen(connection_speed, hidspi, integer, "%s: connection speed = %d\n");
+#define touch_dev_soc_acpigen(field, intf, type, fmt)				\
+	static void touch_acpigen_## intf ## _ ## field(void *arg)		\
+	{									\
+		const struct device *dev = (const struct device *)arg;		\
+		uint32_t value = touch_dev_soc_get(dev, intf, field);		\
+		acpigen_write_debug_sprintf(fmt, touch_acpi_name(dev), value);	\
+		acpigen_write_return_ ## type(value);				\
+	}
+
+touch_dev_soc_acpigen(connection_speed, hidspi, integer, "%s: connection speed = %d\n");
 touch_soc_acpigen(limit_packet_size, hidspi, integer, "%s: limit packet size = %d\n");
 touch_soc_acpigen(performance_limit, hidspi, integer, "%s: performance limit = %d\n");
 
@@ -212,11 +232,12 @@ static void touch_generate_acpi_crs(const struct drivers_intel_touch_config *con
 static void touch_generate_acpi_i2cdev_dsd(const struct device *dev)
 {
 	int dsd_pkg_cnt;
+	uint64_t connection_speed_val;
 
 	acpigen_write_name("ICRS");
 	acpigen_emit_byte(BUFFER_OP);
 	acpigen_write_len_f();
-	acpigen_write_integer(12);
+	acpigen_write_integer(2 + 8 + 1 + 1); /* total size of ICRS + 1 */
 	acpigen_pop_len(); /* Name */
 	acpigen_write_create_buffer_word_field("ICRS", 0x00, "DADR");
 	acpigen_write_create_buffer_qword_field("ICRS", 0x02, "DSPD");
@@ -225,7 +246,7 @@ static void touch_generate_acpi_i2cdev_dsd(const struct device *dev)
 	acpigen_write_name("ISUB");
 	acpigen_emit_byte(BUFFER_OP);
 	acpigen_write_len_f();
-	acpigen_write_integer(145);
+	acpigen_write_integer(22 * 8 + 1); /* total size of ISUB + 1 */
 	acpigen_pop_len();
 	acpigen_write_create_buffer_qword_field("ISUB", 0x00, "SMHX");
 	acpigen_write_create_buffer_qword_field("ISUB", 0x08, "SMLX");
@@ -245,9 +266,29 @@ static void touch_generate_acpi_i2cdev_dsd(const struct device *dev)
 	acpigen_write_create_buffer_qword_field("ISUB", 0x78, "HMTD");
 	acpigen_write_create_buffer_qword_field("ISUB", 0x80, "HMRD");
 	acpigen_write_create_buffer_qword_field("ISUB", 0x88, "HMSL");
+	acpigen_write_create_buffer_qword_field("ISUB", 0x90, "FSEN");
+	acpigen_write_create_buffer_qword_field("ISUB", 0x98, "FSVL");
+	acpigen_write_create_buffer_qword_field("ISUB", 0xa0, "INDE");
+	acpigen_write_create_buffer_qword_field("ISUB", 0xa8, "INDV");
 
 	acpigen_write_store_int_to_namestr(touch_get(dev, dev_hidi2c.intf.hidi2c.addr), "DADR");
-	acpigen_write_store_int_to_namestr(touch_soc_get(dev, hidi2c, connection_speed), "DSPD");
+
+	if (_soc_hidi2c_info->get_soc_i2c_bus_speed_val_func) {
+		enum i2c_speed connection_speed;
+
+		connection_speed = touch_dev_soc_get(dev, hidi2c, connection_speed);
+		/*
+		 * If the recommended speed is not specified in the device tree, SoC, and device,
+		 * standard speed is used.
+		 */
+		if (!connection_speed)
+			connection_speed = I2C_SPEED_STANDARD;
+		connection_speed_val = _soc_hidi2c_info->get_soc_i2c_bus_speed_val_func(
+			connection_speed);
+	} else {
+		die("Missing SoC function to map I2C speed to its register value!\n");
+	}
+	acpigen_write_store_int_to_namestr(connection_speed_val, "DSPD");
 	acpigen_write_store_int_to_namestr(touch_soc_get(dev, hidi2c, addr_mode), "DADM");
 	acpigen_write_store_int_to_namestr(touch_soc_get(dev, hidi2c, sm_scl_high_period), "SMHX");
 	acpigen_write_store_int_to_namestr(touch_soc_get(dev, hidi2c, sm_scl_low_period), "SMLX");
@@ -268,6 +309,21 @@ static void touch_generate_acpi_i2cdev_dsd(const struct device *dev)
 	acpigen_write_store_int_to_namestr(touch_soc_get(dev, hidi2c, hm_sda_hold_rx_period), "HMRD");
 	acpigen_write_store_int_to_namestr(touch_soc_get(dev, hidi2c, suppressed_spikes_h_fp), "HMSL");
 
+	if (get_driver_config(dev)->dev_hidi2c.intf.hidi2c.max_frame_size_value) {
+		acpigen_write_store_int_to_namestr(1, "FSEN");
+		acpigen_write_store_int_to_namestr(touch_get(dev, dev_hidi2c.intf.hidi2c.max_frame_size_value), "FSVL");
+	} else {
+		acpigen_write_store_int_to_namestr(0, "FSEN");
+		acpigen_write_store_int_to_namestr(0, "FSVL");
+	}
+	if (get_driver_config(dev)->dev_hidi2c.intf.hidi2c.interrupt_delay_value) {
+		acpigen_write_store_int_to_namestr(1, "INDE");
+		acpigen_write_store_int_to_namestr(touch_get(dev, dev_hidi2c.intf.hidi2c.interrupt_delay_value), "INDV");
+	} else {
+		acpigen_write_store_int_to_namestr(0, "INDE");
+		acpigen_write_store_int_to_namestr(0, "INDV");
+	}
+
 	dsd_pkg_cnt = 4;
 	if (touch_get(dev, add_acpi_dma_property))
 		dsd_pkg_cnt += 2;
@@ -451,7 +507,6 @@ static void touch_generate_acpi_spidev_rst(const struct drivers_intel_touch_conf
 			acpigen_write_sleep(touch_soc_get(dev, hidspi, reset_sequencing_delay));
 			/* De-assert RESET# GPIO. */
 			acpigen_disable_tx_gpio(&config->soc_hidspi.reset_gpio);
-			acpigen_write_sleep(100); /* Note: use 100 for now */
 			acpigen_write_release(TOUCH_MUTEX);
 		} else
 			acpigen_write_debug_sprintf("%s: _RST() empty method\n",
@@ -510,10 +565,11 @@ static void touch_dev_fill_ssdt_generator(const struct device *dev)
 			touch_generate_acpi_ini(dev);
 			touch_generate_acpi_dsm(config, dev);
 			/* When only THC1 is used, both THC0/1 need to be enabled since THC0's
-			   device function is '0'. In this case, THC0 should set
-			   connected_device to TH_SENSOR_NONE so that when the driver detects
-			   THC0, the _DSM will be available for it to check and exit without
-			   error. */
+			 * device function is '0'. In this case, THC0 should set
+			 * connected_device to TH_SENSOR_NONE so that when the driver detects
+			 * THC0, the _DSM will be available for it to check and exit without
+			 * error.
+			 */
 			if (config->connected_device == TH_SENSOR_NONE)
 				return;
 
