@@ -10,6 +10,7 @@
 enum mec5035_cmd {
 	CMD_MOUSE_TP = 0x1a,
 	CMD_RADIO_CTRL = 0x2b,
+	CMD_POWER_BUTTON_TO_HOST = 0x3e,
 	CMD_CPU_OK = 0xc2,
 };
 
@@ -33,6 +34,11 @@ enum ec_radio_state {
 	RADIO_ON
 };
 
+enum ec_power_button_route {
+	EC = 0,
+	HOST
+};
+
 u8 mec5035_mouse_touchpad(enum ec_mouse_setting setting);
 void mec5035_cpu_ok(void);
 void mec5035_early_init(void);
