@@ -2,14 +2,7 @@
 
 #include <device/azalia_device.h>
 
-const u32 cim_verb_data[] = {
-	/* coreboot specific header */
-	0x10ec0888,
-	0x1025024c,	// Subsystem ID
-	14,	// Number of entries
-
-	/* Pin Widget Verb Table */
-
+static const u32 realtek_alc888_verbs[] = {
 	AZALIA_PIN_CFG(0, 0x11, 0x014b7140),
 	AZALIA_PIN_CFG(0, 0x12, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x14, 0x01014010),
@@ -24,15 +17,32 @@ const u32 cim_verb_data[] = {
 	AZALIA_PIN_CFG(0, 0x1d, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x1e, 0x18567130),
 	AZALIA_PIN_CFG(0, 0x1f, AZALIA_PIN_CFG_NC(0)),
+};
 
-	/* HDMI */
-	0x80862803,
-	0x80860101,
-	1,
-
+static const u32 intel_display_audio_verbs[] = {
 	AZALIA_PIN_CFG(0, 0x03, 0x18560010)
 };
 
 const u32 pc_beep_verbs[0] = {};
 
+struct azalia_codec mainboard_azalia_codecs[] = {
+	{
+		.name         = "Realtek ALC888",
+		.vendor_id    = 0x10ec0888,
+		.subsystem_id = 0x1025024c,
+		.address      = 0,
+		.verbs        = realtek_alc888_verbs,
+		.verb_count   = ARRAY_SIZE(realtek_alc888_verbs),
+	},
+	{
+		.name         = "Intel Display Audio (HDMI/DP)",
+		.vendor_id    = 0x80862803,
+		.subsystem_id = 0x80860101,
+		.address      = 0,
+		.verbs        = intel_display_audio_verbs,
+		.verb_count   = ARRAY_SIZE(intel_display_audio_verbs),
+	},
+	{ /* terminator */ }
+};
+
 AZALIA_ARRAY_SIZES;
