@@ -2,10 +2,7 @@
 
 #include <device/azalia_device.h>
 
-const u32 cim_verb_data[] = {
-	0x11020011,	/* Codec Vendor / Device ID: Creative */
-	0x18491020,	/* Subsystem ID */
-	11,		/* Number of 4 dword sets */
+static const u32 creative_ca0132_verbs[] = {
 	AZALIA_SUBVENDOR(0, 0x18491020),
 	AZALIA_PIN_CFG(0, 0x0b, 0x01014010),
 	AZALIA_PIN_CFG(0, 0x0c, 0x014580f0),
@@ -17,9 +14,20 @@ const u32 cim_verb_data[] = {
 	AZALIA_PIN_CFG(0, 0x12, 0x37a791f0),
 	AZALIA_PIN_CFG(0, 0x13, 0x908700f0),
 	AZALIA_PIN_CFG(0, 0x18, 0x500000f0),
-
 };
 
 const u32 pc_beep_verbs[0] = {};
 
+struct azalia_codec mainboard_azalia_codecs[] = {
+	{
+		.name         = "Creative CA0132",
+		.vendor_id    = 0x11020011,
+		.subsystem_id = 0x18491020,
+		.address      = 0,
+		.verbs        = creative_ca0132_verbs,
+		.verb_count   = ARRAY_SIZE(creative_ca0132_verbs),
+	},
+	{ /* terminator */ }
+};
+
 AZALIA_ARRAY_SIZES;
