@@ -2,13 +2,7 @@
 
 #include <device/azalia_device.h>
 
-const u32 cim_verb_data[] = {
-	/* coreboot specific header */
-	0x10ec0883,	/* Vendor ID */
-	0x104382c7,	/* Subsystem ID */
-	0x0000000c,	/* Number of entries */
-
-	/* Pin Widget Verb Table */
+static const u32 realtek_alc662_verbs[] = {
 	AZALIA_PIN_CFG(0, 0x14, 0x01014010),
 	AZALIA_PIN_CFG(0, 0x15, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x16, AZALIA_PIN_CFG_NC(0)),
@@ -24,4 +18,17 @@ const u32 cim_verb_data[] = {
 };
 
 const u32 pc_beep_verbs[0] = {};
+
+struct azalia_codec mainboard_azalia_codecs[] = {
+	{
+		.name         = "Realtek ALC662",
+		.vendor_id    = 0x10ec0883,
+		.subsystem_id = 0x104382c7,
+		.address      = 0,
+		.verbs        = realtek_alc662_verbs,
+		.verb_count   = ARRAY_SIZE(realtek_alc662_verbs),
+	},
+	{ /* terminator */ }
+};
+
 AZALIA_ARRAY_SIZES;
