@@ -41,6 +41,8 @@
 #endif
 
 void setup_chromeos_gpios(void);
+bool is_off_mode(void);
+void configure_parallel_charging(void);
 void enable_slow_battery_charging(void);
 void disable_slow_battery_charging(void);
 
