@@ -2,6 +2,9 @@
 
 #include <boot/coreboot_tables.h>
 #include <bootmode.h>
+#include <cbmem.h>
+#include <commonlib/bsd/cbmem_id.h>
+#include <commonlib/coreboot_tables.h>
 #include <console/console.h>
 #include <device/device.h>
 #include <ec/google/chromeec/ec.h>
@@ -12,6 +15,33 @@
 #include "board.h"
 #include <soc/usb/usb.h>
 
+/*
+ * This function calls the underlying PMIC/EC function only once during the
+ * first execution and caches the result for all subsequent calls.
+ */
+static enum boot_mode_t get_boot_mode(void)
+{
+	static bool initialized = false;
+	static enum boot_mode_t boot_mode = LB_BOOT_MODE_NORMAL;
+	if (!initialized) {
+		enum boot_mode_t *boot_mode_ptr = cbmem_find(CBMEM_ID_BOOT_MODE);
+		if (boot_mode_ptr)
+			boot_mode = *boot_mode_ptr;
+		printk(BIOS_INFO, "Boot mode is %d\n", boot_mode);
+		initialized = true;
+	}
+	return boot_mode;
+}
+
+static bool is_low_power_boot(void)
+{
+	enum boot_mode_t boot_mode = get_boot_mode();
+	if ((boot_mode == LB_BOOT_MODE_LOW_BATTERY) ||
+	    (boot_mode == LB_BOOT_MODE_OFFMODE_CHARGING))
+		return true;
+	return false;
+}
+
 static void setup_usb(void)
 {
 	setup_usb_host0();
@@ -27,18 +57,19 @@ void lb_add_boot_mode(struct lb_header *header)
 
 	mode->tag = LB_TAG_BOOT_MODE;
 	mode->size = sizeof(*mode);
-	mode->boot_mode = LB_BOOT_MODE_NORMAL;
+	mode->boot_mode = get_boot_mode();
 
-	if (google_chromeec_is_below_critical_threshold())
-		mode->boot_mode = LB_BOOT_MODE_LOW_BATTERY;
-
-	/* Booting into normal mode hence disable charging */
-	if (mode->boot_mode == LB_BOOT_MODE_NORMAL)
-		disable_slow_battery_charging();
+	/* Enable charging only during off-mode or low-battery mode and charger present */
+	if (is_low_power_boot() && google_chromeec_is_charger_present())
+		enable_slow_battery_charging();
 }
 
 bool mainboard_needs_pcie_init(void)
 {
+	/* Skip PCIe initialization if boot mode is "low-battery" or "off-mode charging"*/
+	if (is_low_power_boot())
+		return false;
+
 	return true;
 }
 
@@ -54,6 +85,12 @@ static void display_startup(void)
 
 static void mainboard_init(struct device *dev)
 {
+	configure_parallel_charging();
+
+	/* Skip mainboard initialization if boot mode is "low-battery" or "off-mode charging"*/
+	if (is_low_power_boot())
+		return;
+
 	gpi_firmware_load(QUP_0_GSI_BASE);
 	gpi_firmware_load(QUP_1_GSI_BASE);
 	gpi_firmware_load(QUP_2_GSI_BASE);
@@ -68,7 +105,9 @@ static void mainboard_init(struct device *dev)
 	qupv3_se_fw_load_and_init(QUPV3_1_SE0, SE_PROTOCOL_I2C, MIXED); /* Touch I2C */
 	qupv3_se_fw_load_and_init(QUPV3_1_SE6, SE_PROTOCOL_UART, FIFO); /* BT UART */
 	qupv3_se_fw_load_and_init(QUPV3_0_SE0, SE_PROTOCOL_I2C, MIXED); /* Trackpad I2C */
-	qupv3_se_fw_load_and_init(QUPV3_0_SE1, SE_PROTOCOL_I2C, MIXED); /* USB-A retimer */
+	if (!CONFIG(MAINBOARD_NO_USB_A_PORT))
+		qupv3_se_fw_load_and_init(QUPV3_0_SE1, SE_PROTOCOL_I2C, MIXED); /* USB-A retimer */
+	qupv3_se_fw_load_and_init(QUPV3_0_SE5, SE_PROTOCOL_I2C, MIXED); /* eUSB repeater */
 	if (CONFIG(MAINBOARD_HAS_FINGERPRINT_VIA_SPI))
 		qupv3_se_fw_load_and_init(QUPV3_2_SE2, SE_PROTOCOL_SPI, MIXED); /* Fingerprint SPI */
 
