@@ -6,6 +6,7 @@
 #include <soc/display.h>
 #include <soc/i2c.h>
 #include <soc/tps65132s.h>
+#include <stdbool.h>
 
 #define BRIDGE_I2C		I2C0
 #define PMIC_AW37503_SLAVE	0x3E
@@ -14,7 +15,7 @@
 void aw37503_init(unsigned int bus);
 bool is_pmic_aw37503(unsigned int bus);
 uint32_t panel_id(void);
-void backlight_control(void);
+void backlight_control(bool enable);
 void tps65132s_power_on(struct tps65132s_cfg *config);
 
 /* Return the mipi panel description from given panel id */
