@@ -11,22 +11,22 @@
 /* Fan is at LOW speed */
 #define FAN3_THRESHOLD_OFF	40
 #define FAN3_THRESHOLD_ON	50
-#define FAN3_PWM		0x55
+#define FAN3_PWM		0x62
 
 /* Fan is at MEDIUM speed */
 #define FAN2_THRESHOLD_OFF	55
 #define FAN2_THRESHOLD_ON	67
-#define FAN2_PWM		0xa6
+#define FAN2_PWM		0x86
 
 /* Fan is at HIGH speed */
-#define FAN1_THRESHOLD_OFF	65
-#define FAN1_THRESHOLD_ON	70
-#define FAN1_PWM		0xc0
+#define FAN1_THRESHOLD_OFF	67
+#define FAN1_THRESHOLD_ON	75
+#define FAN1_PWM		0xa8
 
 /* Fan is at FULL speed */
-#define FAN0_THRESHOLD_OFF	90
-#define FAN0_THRESHOLD_ON	100
-#define FAN0_PWM		0xff
+#define FAN0_THRESHOLD_OFF	85
+#define FAN0_THRESHOLD_ON	90
+#define FAN0_PWM		0xdc
 
 /* Temperature which OS will shutdown at */
 #define CRITICAL_TEMPERATURE	104
