@@ -6,12 +6,6 @@
 #include <option.h>
 #include <variants.h>
 
-enum cmos_power_profile get_power_profile(enum cmos_power_profile fallback)
-{
-	const unsigned int power_profile = get_uint_option("power_profile", fallback);
-	return power_profile < NUM_POWER_PROFILES ? power_profile : fallback;
-}
-
 static void init_mainboard(void *chip_info)
 {
 	const struct pad_config *pads;
