@@ -8,6 +8,10 @@
 #include <static.h>
 #include <types.h>
 #include <variants.h>
+#include <common/powercap.h>
+
+#define TJ_MAX		100
+#define TCC(temp)	(TJ_MAX - temp)
 
 void devtree_update(void)
 {
@@ -19,7 +23,7 @@ void devtree_update(void)
 	struct soc_power_limits_config *soc_conf_4core =
 		&cfg->power_limits_config[POWER_LIMITS_U_4_CORE];
 
-	struct device *nic_dev = pcidev_on_root(0x14, 3);
+	struct device *wifi_dev = pcidev_on_root(0x14, 3);
 	struct device *tbt_pci_dev = pcidev_on_root(0x07, 0);
 	struct device *tbt_dma_dev = pcidev_on_root(0x0d, 2);
 	struct device *gna_dev = pcidev_on_root(0x08, 0);
@@ -38,15 +42,15 @@ void devtree_update(void)
 	switch (get_power_profile(PP_POWER_SAVER)) {
 	case PP_POWER_SAVER:
 		performance_scale			-= 50;
-		cfg->tcc_offset				= 30;
+		cfg->tcc_offset				= TCC(80);
 		break;
 	case PP_BALANCED:
 		performance_scale			-= 25;
-		cfg->tcc_offset				= 25;
+		cfg->tcc_offset				= TCC(90);
 		break;
 	case PP_PERFORMANCE:
 		/* Use the Intel defaults */
-		cfg->tcc_offset				= 20;
+		cfg->tcc_offset				= TCC(100);
 		break;
 	}
 
@@ -56,9 +60,13 @@ void devtree_update(void)
 	soc_conf_4core->tdp_pl1_override = (soc_conf_4core->tdp_pl1_override * performance_scale) / 100;
 	soc_conf_4core->tdp_pl2_override = (soc_conf_4core->tdp_pl2_override * performance_scale) / 100;
 
-	/* Enable/Disable Wireless based on CMOS settings */
-	if (get_uint_option("wireless", 1) == 0)
-		nic_dev->enabled = 0;
+	/* Enable/Disable WiFi based on CMOS settings */
+	if (get_uint_option("wifi", 1) == 0)
+		wifi_dev->enabled = 0;
+
+	/* Enable/Disable Bluetooth based on CMOS settings */
+	if (get_uint_option("bluetooth", 1) == 0)
+		cfg->usb2_ports[9].enable = 0;
 
 	/* Enable/Disable Webcam based on CMOS settings */
 	cfg->usb2_ports[CONFIG_CCD_PORT].enable = get_uint_option("webcam", 1);
