@@ -4,21 +4,29 @@
 #define _SOC_QUALCOMM_X1P42100_ADDRESS_MAP_H_
 
 #include <stdint.h>
+#include <types.h>
 
 #define AOSS_CC_BASE			0x0C2A0000
 #define QSPI_BASE			0x088DC000
 #define TLMM_TILE_BASE			0x0F100000
 #define GCC_BASE			0x00100000
 #define NCC0_BASE			0x19A30000
+#define GCC_QUPV3_WRAP0_BASE		0x142004
+#define GCC_QUPV3_WRAP1_BASE		0x118004
+#define GCC_QUPV3_WRAP2_BASE		0x11e004
+#define DISP_PLL0_BASE			0xAF00000
+#define DISP_PLL1_BASE			0xAF01000
+#define DISP_CC_BASE			0xAF08000
 
+#define CBMEM_TOP			0xC7800000
 /* X1P42100 NCC0 PLL CONFIG ADDRESSES */
 #define NCC0_NCC_CMU_NCC_PLL_CFG	0x199A2010
 #define NCC0_NCC_CMU_NCC_CLK_CFG	0x199A2030
 
 /* CPUCP */
 #define APSS_HM_BASE						0x17000000
-#define APSS_CPUCP_LPM_BFSM_REG_BASE				(APSS_HM_BASE + 0x019d0000)
-#define HWIO_APSS_CPUCP_CPUCP_LPM_SEQ_WAIT_EVT_CTRL_MASK_ADDR	(APSS_CPUCP_LPM_BFSM_REG_BASE + 0x161c)
+#define APSS_CPUCP_LPM_BFSM_REG_BASE				(APSS_HM_BASE + 0x019D0000)
+#define HWIO_APSS_CPUCP_CPUCP_LPM_SEQ_WAIT_EVT_CTRL_MASK_ADDR	(APSS_CPUCP_LPM_BFSM_REG_BASE + 0x161C)
 #define HWIO_APSS_CPUCP_CPUCP_SW_WAKEUP_REQ_ADDR		(APSS_CPUCP_LPM_BFSM_REG_BASE + 0x1688)
 
 /* X1P42100 QSPI GPIO PINS */
@@ -69,21 +77,47 @@
 #define QUP_2_GSI_BASE			0x00804000
 
 /* USB BASE ADDRESSES */
-#define HS_USB_MP0_PHY_BASE		0x088e1000
+#define HS_USB_SS0_PHY_BASE		0x00FD3000
+#define HS_USB_SS1_PHY_BASE		0x00FD9000
+#define HS_USB_SS2_PHY_BASE		0x00FDE000
+
+#define HS_USB_MP0_PHY_BASE		0x088E1000
 #define HS_USB_MP1_PHY_BASE		0x088E2000
 #define QMP_PHY_MP0_QSERDES_COM_REG_BASE	0x088E3000
 #define QMP_PHY_MP0_QSERDES_TX_REG_BASE		0x088E3E00
 #define QMP_PHY_MP0_QSERDES_RX_REG_BASE		0x088E4000
-#define QMP_PHY_MP0_PCS_REG_BASE			0x088E3200
+#define QMP_PHY_MP0_PCS_REG_BASE		0x088E3200
 #define QMP_PHY_MP0_PCS_USB3_REG_BASE		0x088E4200
-#define USB_HOST_DWC3_BASE					0x0a40c100
+#define USB_HOST_DWC3_MP_BASE			0x0A40C100
 
 #define QMP_PHY_MP1_QSERDES_COM_REG_BASE	0x088E5000
 #define QMP_PHY_MP1_QSERDES_TX_REG_BASE		0x088E5E00
 #define QMP_PHY_MP1_QSERDES_RX_REG_BASE		0x088E6000
-#define QMP_PHY_MP1_PCS_REG_BASE			0x088E5200
+#define QMP_PHY_MP1_PCS_REG_BASE		0x088E5200
 #define QMP_PHY_MP1_PCS_USB3_REG_BASE		0x088E6200
 
+/* USB SS0 PHY BASE ADDRESSES - AHB2PHY_1_QUSB4PHY_SS_0 */
+#define QMP_PHY_SS0_COM_REG_BASE		0x00FD5000	/* USB43DP_COM */
+#define QMP_PHY_SS0_TXA_REG_BASE		0x00FD5400	/* USB43DP_QSERDES_TXA */
+#define QMP_PHY_SS0_TXB_REG_BASE		0x00FD5A00	/* USB43DP_QSERDES_TXB */
+#define QMP_PHY_SS0_RXA_REG_BASE		0x00FD5600	/* USB43DP_QSERDES_RXA */
+#define QMP_PHY_SS0_RXB_REG_BASE		0x00FD5C00	/* USB43DP_QSERDES_RXB */
+#define QMP_PHY_SS0_QSERDES_PLL_REG_BASE	0x00FD6000	/* USB3_QSERDES_PLL */
+#define QMP_PHY_SS0_PCS_REG_BASE		0x00FD6400	/* USB3_PCS */
+#define QMP_PHY_SS0_PCS_USB3_REG_BASE		0x00FD6700	/* USB3_PCS_USB3 */
+#define USB_HOST_DWC3_PRIM_BASE			0x0A60C100
+
+/* USB SS1 PHY BASE ADDRESSES - AHB2PHY_1_QUSB4PHY_SS_1 */
+#define QMP_PHY_SS1_COM_REG_BASE		0x00FDA000	/* USB43DP_COM */
+#define QMP_PHY_SS1_TXA_REG_BASE		0x00FDA400	/* USB43DP_QSERDES_TXA */
+#define QMP_PHY_SS1_TXB_REG_BASE		0x00FDAA00	/* USB43DP_QSERDES_TXB */
+#define QMP_PHY_SS1_RXA_REG_BASE		0x00FDA600	/* USB43DP_QSERDES_RXA */
+#define QMP_PHY_SS1_RXB_REG_BASE		0x00FDAC00	/* USB43DP_QSERDES_RXB */
+#define QMP_PHY_SS1_QSERDES_PLL_REG_BASE	0xFDB000	/* USB3_QSERDES_PLL */
+#define QMP_PHY_SS1_PCS_REG_BASE		0xFDB400	/* USB3_PCS */
+#define QMP_PHY_SS1_PCS_USB3_REG_BASE		0xFDB700	/* USB3_PCS_USB3 */
+#define USB_HOST_DWC3_SEC_BASE				0x0A80C100
+
 /* PCIE 6A */
 #define PCIE6A_PCIE_PARF		0x01BF8000
 #define PCIE6A_GEN1X4_PCIE_DBI		0x70000000
@@ -140,7 +174,22 @@
 
 #define TCSR_GCC_USB3_MP0_CLKREF_EN_ADDR	((void *)0x1FD510C)
 #define TCSR_GCC_USB3_MP1_CLKREF_EN_ADDR	((void *)0x1FD5110)
-#define USB3_CLKREF_ENABLE_VALUE			0x1
+#define TCSR_GCC_USB4_1_CLKREF_EN_ADDR		((void *)0x1FD5120)
+#define TCSR_GCC_USB2_1_CLKREF_EN_ADDR		((void *)0x1FD5114)
+#define TCSR_GCC_USB4_2_CLKREF_EN_ADDR		((void *)0x1FD5124)
+#define TCSR_GCC_USB2_2_CLKREF_EN_ADDR		((void *)0x1FD5118)
+#define TCSR_GCC_EDP_CLKREF_EN_ADDR		((void *)0x1FD5130)
+#define USB_CLKREF_ENABLE_VALUE			0x1
+
+/* TCSR Boot Misc Detect Register for Download Mode */
+#define TCSR_BOOT_MISC_DETECT		0x1FD9000
+
+/* Bits 4 and 5 represent the ramdump download cookies in SoC logic */
+enum dload_mode_cookies {
+	DLOAD_FULL_DUMP = BIT(4),
+	DLOAD_MINI_DUMP = BIT(5),
+	DLOAD_BOTH = (DLOAD_FULL_DUMP | DLOAD_MINI_DUMP)
+};
 
 /* SPMI PMIC ARB */
 #define SPMI_PMIC_ARB_CORE_BASE		0x0C400000
